#
# spec file for package gtkspell
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gtkspell
Version:        2.0.16
Release:        24.7
# FIXME: Replace Obsoletes <= version with Obsoletes < version in libgtkspell0 subpackage on update (after 2.0.16)
Summary:        GTK2 Spell Checker Interface Library
License:        GPL-2.0-or-later
Group:          System/Libraries
URL:            http://gtkspell.sf.net/
Source:         %{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  intltool
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(enchant) >= 0.4.0
BuildRequires:  pkgconfig(gtk+-2.0)

%description
GtkSpell provides MSWord-style and MacOSX-style highlighting of
misspelled words in a GtkTextView widget. Right-clicking a misspelled
word opens a menu of suggested replacements.

%package -n libgtkspell0
Summary:        GTK2 Spell Checker Interface Library
Group:          System/Libraries
# Needed to make lang package installable
Provides:       gtkspell = %{version}
# SLPP applied during development of 12.1. gtkspell last shipped in 11.4
# Change <= to < on update to new version (> 2.0.16)
Obsoletes:      gtkspell <= %{version}

%description -n libgtkspell0
GtkSpell provides MSWord-style and MacOSX-style highlighting of
misspelled words in a GtkTextView widget. Right-clicking a misspelled
word opens a menu of suggested replacements.

%package      devel
Summary:        Static libraries and header files from gtkspell
Group:          Development/Libraries/X11
Requires:       libgtkspell0 = %{version}

%description devel
Static libraries and header files from gtkspell.

%package      doc
Summary:        GTK2 Spell Checker Interface Library
Group:          System/Libraries
Requires:       libgtkspell0 = %{version}

%description doc
GtkSpell provides MSWord-style and MacOSX-style highlighting of
misspelled words in a GtkTextView widget. Right-clicking a misspelled
word opens a menu of suggested replacements.

%lang_package

%prep
%setup -q %{name}-%{version}

%build
%configure\
	--disable-static \
	--enable-gtk-doc=no
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%post -n libgtkspell0 -p /sbin/ldconfig
%postun -n libgtkspell0 -p /sbin/ldconfig

%files -n libgtkspell0
%license COPYING
%doc AUTHORS ChangeLog README
%{_libdir}/*.so.*

%files lang -f %{name}.lang

%files devel
%{_includedir}/gtkspell-2.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%{_datadir}/gtk-doc/

%changelog
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Own /usr/share/gtk-doc: glib no longer uses gtk-doc and as a
  consequence cannot be held responsible to deliver that basic
  directory structure.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Dec 14 2017 dimstar@opensuse.org
- Replace enchant-devel and gtk2-devel BuildRequires with their
  pkgconfig() equivalents: pkgconfig(enchant) and
  pkgconfig(gtk+-2.0).
* Tue Aug 15 2017 zaitor@opensuse.org
- Drop gtk-doc BuildRequires and pass --enable-gtk-doc=no to
  configure, needed with gtk-doc 1.26 and newer, as gtkdoc-mktmpl
  was dropped from it.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Fri Jun 17 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Tue May  3 2011 dimstar@opensuse.org
- bnc#691401: SLPP for gtkspell:
  + Create new subpackage libgtkspell0 with gtkspell
    Provides/Obsoletes for proper upgrade path.
  + Move -lang Recommends to the lib-package.
- Remove explicit Requires for gtk2-devel,g lib2-devel,
  pango-devel, atk-devel and enchant-devel from the -devel package:
  they will automatically be added the pkgconfig() way.
- Clean spec file using spec-cleaner.
* Mon May  2 2011 vuntz@opensuse.org
- Remove now unneeded call to autoreconf.
- Do not package .la files.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to 2.0.16:
  + Additional and updated translations (see po/ChangeLog).
  + sf#2431005: Language codes that contain "C" (e.g. "cs_CZ")
    defaulted to "en"
  + sf#2715972: Remove an extra comma at the end of the
    GtkSpellError enum definition.
  + sf#2526949: Sort languages list submenu.
  + sf#2526959: Currently selected language appears with radio
    button selection in Language selector sub-menu
  + sf#2642198: Enchant Broker should be a singleton.
  + sf#2875116 Support changing of the GtkTextBuffer in the
    attached GtkTextView.
- Use source services: download_url, recompress and set_version.
- Drop gtkspell-locale.patch: fixed upstream.
* Tue Feb 22 2011 sbrabec@suse.cz
- Added support for translation-update-upstream (bnc#673924).
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Tue Feb 10 2009 pgajdos@suse.cz
- removed redundant aspell-devel from BuildRequires [fate#305688]
* Tue Jan 13 2009 pgajdos@suse.cz
- updated to version 2.0.15:
  * Additional translations (see po/ChangeLog).
  * Add missing G_BEGIN_DECLS/G_END_DECLS for C++ support
  * Fix feature request #2101451 by removing the sub-menu
    of the context menu as any other in-line spell checker does.
  * Fix feature request #1523881, #1643622 and #2054637
    by adding a Language selector sub-menu.
  * Fix feature request #1362304 by fixing docs/Makefile.am
    to install gtkspell.devhelp so that it shows in devhelp
* Mon Sep 29 2008 pgajdos@suse.cz
- fixed [bnc#389339]
  * locale.patch
* Mon Aug 18 2008 lmichnovic@suse.cz
- update to version 2.0.14
  * Additional translations (see po/ChangeLog).
  * Changed bug reporting address at configure.ac:AC_INIT
  * undo/redo in the calling application (Liviu Andronic)
  * gtkspell_get_suggestions_menu() (Liviu Andronic)
* Tue Aug 12 2008 lmichnovic@suse.cz
- added intltool into BuildReq
* Tue Aug 12 2008 lmichnovic@suse.cz
- update to version 2.0.13
  * Additional translations (see po/ChangeLog).
  * Enchant support (support for pspell/aspell dropped)
- obsoletes *-enchant.patch *-gcc-err-fix.patch
- version 2.0.12:
  * Make debug, quiet and build_suggestion_menu static in
  gtkspell.c to prevent exporting them.
  * One additional translation (see po/ChangeLog).
  * Move spell-checking library from Libs to Libs.private in
  gtkspell-2.0.pc
  * Update autogen.sh to use intltool
  * Fix warnings with -Wstrict-prototypes by Richard Laager
* Fri Feb  1 2008 lmichnovic@suse.cz
- enabled enchant support in gtkspell (*-enchant.patch)
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Fri Jan 12 2007 sbrabec@suse.cz
- More spec file cleanups.
* Mon Jan  8 2007 lmichnovic@suse.cz
- changed prefix because GNOME moved to /usr
* Wed Dec 13 2006 maw@suse.de
- Do some specfile cleanup.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 19 2005 pnemec@suse.cz
- fix gcc 4.1 warning
* Mon Aug  1 2005 ro@suse.de
- use gtk2-devel-packages in nfb
* Tue May 31 2005 ltinkl@suse.cz
- update to 2.0.11
* Tue Apr 12 2005 ltinkl@suse.cz
- update to 2.0.10
* Wed Oct 27 2004 ltinkl@suse.cz
- update to version 2.0.8
* Sat Apr 24 2004 sndirsch@suse.de
- fixed neededforbuild (using x-devel-packages now)
* Wed Jan 28 2004 ltinkl@suse.cz
- update to 2.0.5
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Dec  5 2003 ro@suse.de
- fix typo in specfile (run_ldconfig on own line)
* Tue Jul 22 2003 hhetter@suse.de
- really prefix to /opt/gnome
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun  5 2003 ltinkl@suse.cz
- initial version (2.0.4)
